import analogio
import audiobusio
import board
import digitalio
import time

from helpers import zufaellige_audiodatei


# Der Bodenfeuchtesensor liefert Werte zwische 0 und 65535.
# Je trockener die Erde ist, desto größer ist der Messwert.
# Messwerte über dieser Grenze lassen die Pflanze meckern.
ZU_TROCKEN = 45000

# Die Pause, die die Pflanze haben soll, bevor sie wieder
# einen Hausbewohner vollmeckert. >.<
MECKERPAUSE = 11

# In diesem Ordner werden die Musikdateien erwartet.
# Es werden .wav-Dateien benötigt!
WAV_ORDNER = "/wav"

# Der Anschluss für den Bodenfeuchtesensor.
BODENFEUCHTE_PIN = board.IO7

# Der Anschluss für den Bewegungsmeldersensor.
BEWEGUNG_PIN = board.IO9

# Die Anschlüsse für den MAX98357 (I2S Decoder und Verstärker).
# Mit dem I2S Protokoll können Audioinhalte zwischen Chips
# übertragen werden.
I2S_BCLK_PIN = board.IO35
I2S_WS_PIN = board.IO37
I2S_DATA_PIN = board.IO33


# Der Bodenfeuchtesensor
bodenfeuchte = analogio.AnalogIn(BODENFEUCHTE_PIN)

# Der HC-SR501 Bewegungsmelder misst Wärmestrahlung.
bewegung = digitalio.DigitalInOut(BEWEGUNG_PIN)
bewegung.direction = digitalio.Direction.INPUT

# Der Audio Player
audio = audiobusio.I2SOut(
    I2S_BCLK_PIN,
    I2S_WS_PIN,
    I2S_DATA_PIN
)


while True:
    messwert = bodenfeuchte.value
    bewegungsstatus = bewegung.value
    print(f"Die Bodenfeuchtigkeit beträgt: {messwert}") # Messwert ausgeben
    
    if messwert > ZU_TROCKEN and bewegungsstatus:
        print("Die Erde ist zu trocken und es beweget sich etwas.")
        wave = zufaellige_audiodatei(WAV_ORDNER)
        audio.play(wave)        # Wenn Bewegung und Erde trocken spiele eine Datei ab
        time.sleep(MECKERPAUSE) # Eine Pause, nicht direkt nochmal reagieren
    else:
        print("Die Erde ist okay oder es ist niemand da...") # Alles tutti
        time.sleep(0.5)
